@@ -177,6 +177,40 @@ const OSM_FIELDS = [
                   ['wired', _("Wired")],
                   ['terminal', _("Terminal")],
                   ['service', _("Service")]]
+    },
+    {
+        name: _("Religion"),
+        tag: 'religion',
+        type: EditFieldType.COMBO,
+        options: [['animist', _("Animism")],
+                  ['bahai', _("Bahá'í")],
+                  ['buddhist', _("Buddhism")],
+                  ['caodaism', _("Caodaism")],
+                  ['christian', _("Christianity")],
+                  ['confucian', _("Confucianism")],
+                  ['hindu', _("Hinduism")],
+                  ['jain', _("Jainism")],
+                  ['jewish', _("Judaism")],
+                  ['muslim', _("Islam")],
+                  ['multifaith', _("Multiple Religions")],
+                  ['pagan', _("Paganism")],
+                  ['pastafarian', _("Pastafarianism")],
+                  ['scientologist', _("Scientology")],
+                  ['shinto', _("Shinto")],
+                  ['sikh', _("Sikhism")],
+                  ['spiritualist', _("Spiritualism")],
+                  ['taoist', _("Taoism")],
+                  ['unitarian_universalist', _("Unitarian Universalism")],
+                  ['voodoo', _("Voodoo")],
+                  ['yazidi', _("Yazidism")],
+                  ['zoroastrian', _("Zoroastrianism")]]
+    },
+    {
+        name: _("Toilets"),
+        tag: 'toilets',
+        type: EditFieldType.COMBO,
+        options: [['yes', _("Yes")],
+                  ['no', _("No")]]
     }];
 
 const OSMEditAddress = new Lang.Class({
@@ -462,6 +496,7 @@ const OSMEditDialog = new Lang.Class({
         this._backButton.visible = true;
         this._cancelButton.visible = false;
         this._isEditing = false;
+        this._commentTextView.grab_focus();
     },
 
     _onCancelClicked: function() {
@@ -575,11 +610,12 @@ const OSMEditDialog = new Lang.Class({
     },
 
     _showHintPopover: function(entry, hint) {
-        this._hintPopover.visible = !this._hintPopover.visible;
         if (this._hintPopover.visible) {
+            this._hintPopover.popdown();
+        } else {
             this._hintPopover.relative_to = entry;
             this._hintLabel.label = hint;
-            this._hintPopover.visible = true;
+            this._hintPopover.popup();
         }
     },
 
@@ -608,6 +644,7 @@ const OSMEditDialog = new Lang.Class({
 
         this._editorGrid.attach(entry, 1, this._currentRow, 1, 1);
         entry.show();
+        entry.grab_focus();
 
         /* TODO: should we allow deleting the name field? */
         this._addOSMEditDeleteButton(fieldSpec);
@@ -636,6 +673,7 @@ const OSMEditDialog = new Lang.Class({
 
         this._editorGrid.attach(spinbutton, 1, this._currentRow, 1, 1);
         spinbutton.show();
+        spinbutton.grab_focus();
 
         this._addOSMEditDeleteButton(fieldSpec);
         this._currentRow++;
@@ -658,6 +696,7 @@ const OSMEditDialog = new Lang.Class({
 
         this._editorGrid.attach(combobox, 1, this._currentRow, 1, 1);
         combobox.show();
+        combobox.grab_focus();
 
         this._addOSMEditDeleteButton(fieldSpec);
         this._currentRow++;
@@ -682,6 +721,7 @@ const OSMEditDialog = new Lang.Class({
 
         let rows = fieldSpec.rows || 1;
         this._editorGrid.attach(addr, 1, this._currentRow, 1, rows);
+        addr.street.grab_focus();
         this._addOSMEditDeleteButton(fieldSpec);
         this._currentRow += rows;
     },
